package at.jku.ssw.sort;

import java.util.Comparator;

@SuppressWarnings("rawtypes")
public abstract class Sorter {
	public enum SortingOrder {
		ASCENDING, DECENDING
	}

	/**
	 * Sorts the object object array by using the supplied comparator. The
	 * specific implementations decide if the items array itself is sorted in
	 * place. This method just guarantees that the resulting array is sorted.
	 * 
	 * 
	 * @param items
	 *            the array to be sorted
	 * @param cmp
	 *            a comparator that is used to compare the items during sorting
	 * 
	 * @param ordering
	 *            determines if the array should be sorted in
	 *            {@link SortingOrder#ASCENDING ascending} or
	 *            {@link SortingOrder#DECENDING descending} order
	 * 
	 * @return a sorted array representing the items array parameter, might be
	 *         the same array as items or not depending on the implementation
	 */
	public abstract Object[] sort(Object[] items, Comparator cmp, SortingOrder ordering);

}
